@@ -18,6 +18,10 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
+#if defined( HAVE_CONFIG_H )
+# include "config.h"
+#endif
+
 #include <tqlayout.h>
 
 #include <tdelocale.h>
@@ -68,9 +72,9 @@ K_EXPORT_COMPONENT_FACTORY( kcm_gtk, KcmGtkFactory("gtk"))*/
 
 extern "C"
 {
-	TDECModule *create_kcmgtk( TQWidget * parent, const char * name )
+	KDE_EXPORT TDECModule *create_kcmgtk( TQWidget * parent, const char * name )
 	{
-		TDEGlobal::locale()->insertCatalogue( "gtkqtengine" );
+		TDEGlobal::locale()->insertCatalogue( "gtk-qt-engine" );
 		return new KcmGtk( parent, "kcmgtk" );
 	}
 }
@@ -165,7 +169,7 @@ KcmGtk::KcmGtk(TQWidget *parent, const char *name, const TQStringList&)
       emacsDetailsDialog(NULL),
       searchPathsDialog(NULL)
 {
-	TDEGlobal::locale()->insertCatalogue("gtkqtengine");
+	TDEGlobal::locale()->insertCatalogue("gtk-qt-engine");
 	
 	config = new TDEConfig("kcmgtkrc");
 
