@@ -109,10 +109,10 @@ Atom desktopWindowAtom;
 static const int argc_fake = 2;
 static char** argv_fake;
 
-static TDEAboutData aboutData("gtk-qt-engine", I18N_NOOP("gtk-qt-engine"), "v0.1",
-	"GTK Qt theme engine", TDEAboutData::License_GPL,
+static TDEAboutData aboutData("gtk2-tqt-engine", I18N_NOOP("gtk2-tqt-engine"), "v0.1",
+	"GTK2 TQt theme engine", TDEAboutData::License_GPL,
 	"(c) 2011-2014, Trinity Desktop Project",
-	"A Qt theme engine for GTK Applications", "https://www.trinitydesktop.org/", 0);
+	"A TQt theme engine for GTK2 Applications", "https://www.trinitydesktop.org/", 0);
 
 void setFillPixmap(GdkPixbuf* buf)
 {
